;; Generated package description from osc.el  -*- no-byte-compile: t -*-
(define-package "osc" "0.4.0.20221221.81343" "Open Sound Control protocol library" 'nil :commit "62eda3d8fb288b6a16c35a7220a507d0991c5a74" :url "https://elpa.gnu.org/packages/osc.html" :authors '(("Mario Lang" . "mlang@blind.guru")) :maintainer '("Mario Lang" . "mlang@blind.guru") :keywords '("comm" "processes" "multimedia"))
